@@ -57,7 +57,7 @@ __PACKAGE__->meta->make_immutable;
 
 package Paws;
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 use Moose;
 use MooseX::ClassAttribute;
@@ -238,6 +238,8 @@ L<Paws::ACM>
 
 L<Paws::ApiGateway>
 
+L<Paws::ApplicationAutoScaling>
+
 L<Paws::AutoScaling>
 
 L<Paws::CloudFormation>
@@ -280,6 +282,8 @@ L<Paws::DeviceFarm>
 
 L<Paws::DirectConnect>
 
+L<Paws::Discovery>
+
 L<Paws::DMS>
 
 L<Paws::DS>
@@ -574,6 +578,10 @@ This code is distributed under the Apache 2 License. The full text of the licens
 
 =head1 CONTRIBUITIONS
 
+
+CAPSiDE (http://www.capside.com) for letting Paws be contributed in an open source model 
+and giving me time to build and maintain it regularly
+
 Luis Alberto Gimenez (@agimenez) for 
  - The git-fu cleaning up the "pull other sdks" code
  - Credential Providers code
