@@ -40,45 +40,50 @@ Values for attributes that are native types (Int, String, Float, etc) can passed
 
 =head2 AutoScalingGroupName => Str
 
-  The name of the group.
+The name of the group.
+
 
 
 =head2 EndTime => Str
 
-  The latest scheduled start time to return. If scheduled action names
+The latest scheduled start time to return. If scheduled action names
 are provided, this parameter is ignored.
 
 
+
 =head2 MaxRecords => Int
 
-  The maximum number of items to return with this call.
+The maximum number of items to return with this call.
+
 
 
 =head2 NextToken => Str
 
-  The token for the next set of items to return. (You received this token
+The token for the next set of items to return. (You received this token
 from a previous call.)
 
 
+
 =head2 ScheduledActionNames => ArrayRef[Str]
 
-  Describes one or more scheduled actions. If you omit this list, the
+Describes one or more scheduled actions. If you omit this list, the
 call describes all scheduled actions. If you specify an unknown
 scheduled action it is ignored with no error.
 
 You can describe up to a maximum of 50 instances with a single call. If
 there are more items to return, the call returns a token. To get the
-next set of items, repeat the call with the returned token in the
-C<NextToken> parameter.
+next set of items, repeat the call with the returned token.
+
 
 
 =head2 StartTime => Str
 
-  The earliest scheduled start time to return. If scheduled action names
+The earliest scheduled start time to return. If scheduled action names
 are provided, this parameter is ignored.
 
 
 
+
 =head1 SEE ALSO
 
 This class forms part of L<Paws>, documenting arguments for method DescribeScheduledActions in L<Paws::AutoScaling>
