@@ -16,15 +16,18 @@ Paws::CodeDeploy::ListDeploymentConfigsOutput
 
 =head2 DeploymentConfigsList => ArrayRef[Str]
 
-  A list of deployment configurations, including the built-in
-configurations such as CodeDeployDefault.OneAtATime.
+A list of deployment configurations, including built-in configurations
+such as CodeDeployDefault.OneAtATime.
+
+
 
 =head2 NextToken => Str
 
-  If the amount of information that is returned is significantly large,
-an identifier will also be returned, which can be used in a subsequent
-list deployment configurations call to return the next set of
-deployment configurations in the list.
+If a large amount of information is returned, an identifier is also
+returned. It can be used in a subsequent list deployment configurations
+call to return the next set of deployment configurations in the list.
+
+
 
 
 =cut
