@@ -2,6 +2,7 @@
 package Paws::CognitoIdentity::UpdateIdentityPool;
   use Moose;
   has AllowUnauthenticatedIdentities => (is => 'ro', isa => 'Bool', required => 1);
+  has CognitoIdentityProviders => (is => 'ro', isa => 'ArrayRef[Paws::CognitoIdentity::CognitoIdentityProvider]');
   has DeveloperProviderName => (is => 'ro', isa => 'Str');
   has IdentityPoolId => (is => 'ro', isa => 'Str', required => 1);
   has IdentityPoolName => (is => 'ro', isa => 'Str', required => 1);
@@ -44,6 +45,12 @@ TRUE if the identity pool supports unauthenticated logins.
 
 
 
+=head2 CognitoIdentityProviders => ArrayRef[L<Paws::CognitoIdentity::CognitoIdentityProvider>]
+
+A list representing a Cognito User Identity Pool and its client ID.
+
+
+
 =head2 DeveloperProviderName => Str
 
 The "domain" by which Cognito will refer to your users.
