@@ -4,10 +4,14 @@ package Paws::DynamoDB;
   sub version { '2012-08-10' }
   sub target_prefix { 'DynamoDB_20120810' }
   sub json_version { "1.0" }
-  has max_attempts => (is => 'ro', isa => 'Int', default => 5);
+  has max_attempts => (is => 'ro', isa => 'Int', default => 10);
   has retry => (is => 'ro', isa => 'HashRef', default => sub {
-    { base => 'rand', type => 'exponential', growth_factor => 2 }
+    { base => '0.05', type => 'exponential', growth_factor => 2 }
   });
+  has retriables => (is => 'ro', isa => 'ArrayRef', default => sub { [
+       sub { defined $_[0]->http_status and $_[0]->http_status == 400 and $_[0]->code eq 'ProvisionedThroughputExceededException' },
+       sub { $_[0]->code eq 'Crc32Error' },
+  ] });
 
   with 'Paws::API::Caller', 'Paws::API::EndpointResolver', 'Paws::Net::V4Signature', 'Paws::Net::JsonCaller', 'Paws::Net::JsonResponse';
 
@@ -61,6 +65,11 @@ package Paws::DynamoDB;
     my $call_object = $self->new_with_coercions('Paws::DynamoDB::DeleteTable', @_);
     return $self->caller->do_call($self, $call_object);
   }
+  sub DescribeLimits {
+    my $self = shift;
+    my $call_object = $self->new_with_coercions('Paws::DynamoDB::DescribeLimits', @_);
+    return $self->caller->do_call($self, $call_object);
+  }
   sub DescribeTable {
     my $self = shift;
     my $call_object = $self->new_with_coercions('Paws::DynamoDB::DescribeTable', @_);
@@ -102,7 +111,7 @@ package Paws::DynamoDB;
     return $self->caller->do_call($self, $call_object);
   }
 
-  sub operations { qw/BatchGetItem BatchWriteItem CreateTable DeleteItem DeleteTable DescribeTable GetItem ListTables PutItem Query Scan UpdateItem UpdateTable / }
+  sub operations { qw/BatchGetItem BatchWriteItem CreateTable DeleteItem DeleteTable DescribeLimits DescribeTable GetItem ListTables PutItem Query Scan UpdateItem UpdateTable / }
 
 1;
 
@@ -132,12 +141,34 @@ Paws::DynamoDB - Perl Interface to AWS Amazon DynamoDB
 
 Amazon DynamoDB
 
-B<Overview>
-
 This is the Amazon DynamoDB API Reference. This guide provides
-descriptions and samples of the low-level DynamoDB API. For information
-about DynamoDB application development, see the Amazon DynamoDB
-Developer Guide.
+descriptions of the low-level DynamoDB API.
+
+This guide is intended for use with the following DynamoDB
+documentation:
+
+=over
+
+=item *
+
+Amazon DynamoDB Getting Started Guide - provides hands-on exercises
+that help you learn the basics of working with DynamoDB. I<If you are
+new to DynamoDB, we recommend that you begin with the Getting Started
+Guide.>
+
+=item *
+
+Amazon DynamoDB Developer Guide - contains detailed information about
+DynamoDB concepts, usage, and best practices.
+
+=item *
+
+Amazon DynamoDB Streams API Reference - provides descriptions and
+samples of the DynamoDB Streams API. (For more information, see
+Capturing Table Activity with DynamoDB Streams in the Amazon DynamoDB
+Developer Guide.)
+
+=back
 
 Instead of making the requests to the low-level DynamoDB API directly
 from your application, we recommend that you use the AWS Software
@@ -145,8 +176,8 @@ Development Kits (SDKs). The easy-to-use libraries in the AWS SDKs make
 it unnecessary to call the low-level DynamoDB API directly from your
 application. The libraries take care of request authentication,
 serialization, and connection management. For more information, see
-Using the AWS SDKs with DynamoDB in the I<Amazon DynamoDB Developer
-Guide>.
+Using the AWS SDKs with DynamoDB in the Amazon DynamoDB Developer
+Guide.
 
 If you decide to code against the low-level DynamoDB API directly, you
 will need to write the necessary code to authenticate your requests.
@@ -163,11 +194,10 @@ B<Managing Tables>
 =item *
 
 I<CreateTable> - Creates a table with user-specified provisioned
-throughput settings. You must designate one attribute as the hash
-primary key for the table; you can optionally designate a second
-attribute as the range primary key. DynamoDB creates indexes on these
-key attributes for fast data access. Optionally, you can create one or
-more secondary indexes, which provide fast data access using non-key
+throughput settings. You must define a primary key for the table -
+either a simple primary key (partition key), or a composite primary key
+(partition key and sort key). Optionally, you can create one or more
+secondary indexes, which provide fast data access using non-key
 attributes.
 
 =item *
@@ -217,10 +247,10 @@ consistent reads can be used.
 =item *
 
 I<Query> - Returns one or more items from a table or a secondary index.
-You must provide a specific hash key value. You can narrow the scope of
-the query using comparison operators against a range key value, or on
-the index key. I<Query> supports either eventual or strong consistency.
-A single response has a size limit of 1 MB.
+You must provide a specific value for the partition key. You can narrow
+the scope of the query using comparison operators against a sort key
+value, or on the index key. I<Query> supports either eventual or strong
+consistency. A single response has a size limit of 1 MB.
 
 =item *
 
@@ -524,6 +554,83 @@ the stream is automatically deleted after 24 hours.
 Use the I<DescribeTable> API to check the status of the table.
 
 
+=head2 DescribeLimits()
+
+Each argument is described in detail in: L<Paws::DynamoDB::DescribeLimits>
+
+Returns: a L<Paws::DynamoDB::DescribeLimitsOutput> instance
+
+  Returns the current provisioned-capacity limits for your AWS account in
+a region, both for the region as a whole and for any one DynamoDB table
+that you create there.
+
+When you establish an AWS account, the account has initial limits on
+the maximum read capacity units and write capacity units that you can
+provision across all of your DynamoDB tables in a given region. Also,
+there are per-table limits that apply when you create a table there.
+For more information, see Limits page in the I<Amazon DynamoDB
+Developer Guide>.
+
+Although you can increase these limits by filing a case at AWS Support
+Center, obtaining the increase is not instantaneous. The
+I<DescribeLimits> API lets you write code to compare the capacity you
+are currently using to those limits imposed by your account so that you
+have enough time to apply for an increase before you hit a limit.
+
+For example, you could use one of the AWS SDKs to do the following:
+
+=over
+
+=item 1. Call I<DescribeLimits> for a particular region to obtain your
+current account limits on provisioned capacity there.
+
+=item 2. Create a variable to hold the aggregate read capacity units
+provisioned for all your tables in that region, and one to hold the
+aggregate write capacity units. Zero them both.
+
+=item 3. Call I<ListTables> to obtain a list of all your DynamoDB
+tables.
+
+=item 4. For each table name listed by I<ListTables>, do the following:
+
+=over
+
+=item * Call I<DescribeTable> with the table name.
+
+=item * Use the data returned by I<DescribeTable> to add the read
+capacity units and write capacity units provisioned for the table
+itself to your variables.
+
+=item * If the table has one or more global secondary indexes (GSIs),
+loop over these GSIs and add their provisioned capacity values to your
+variables as well.
+
+=back
+
+=item 5. Report the account limits for that region returned by
+I<DescribeLimits>, along with the total current provisioned capacity
+levels you have calculated.
+
+=back
+
+This will let you see whether you are getting close to your
+account-level limits.
+
+The per-table limits apply only when you are creating a new table. They
+restrict the sum of the provisioned capacity of the new table itself
+and all its global secondary indexes.
+
+For existing tables and their GSIs, DynamoDB will not let you increase
+provisioned capacity extremely rapidly, but the only upper limit that
+applies is that the aggregate provisioned capacity over all your tables
+and GSIs cannot exceed either of the per-account limits.
+
+I<DescribeLimits> should only be called periodically. You can expect
+throttling errors if you call it more than once in a minute.
+
+The I<DescribeLimits> Request element has no content.
+
+
 =head2 DescribeTable(TableName => Str)
 
 Each argument is described in detail in: L<Paws::DynamoDB::DescribeTable>
@@ -534,11 +641,12 @@ Returns: a L<Paws::DynamoDB::DescribeTableOutput> instance
 the table, when it was created, the primary key schema, and any indexes
 on the table.
 
-If you issue a DescribeTable request immediately after a CreateTable
-request, DynamoDB might return a ResourceNotFoundException. This is
-because DescribeTable uses an eventually consistent query, and the
-metadata for your table might not be available at that moment. Wait for
-a few seconds, and then try the DescribeTable request again.
+If you issue a I<DescribeTable> request immediately after a
+I<CreateTable> request, DynamoDB might return a
+I<ResourceNotFoundException>. This is because I<DescribeTable> uses an
+eventually consistent query, and the metadata for your table might not
+be available at that moment. Wait for a few seconds, and then try the
+I<DescribeTable> request again.
 
 
 =head2 GetItem(Key => L<Paws::DynamoDB::Key>, TableName => Str, [AttributesToGet => ArrayRef[Str], ConsistentRead => Bool, ExpressionAttributeNames => L<Paws::DynamoDB::ExpressionAttributeNameMap>, ProjectionExpression => Str, ReturnConsumedCapacity => Str])
@@ -598,8 +706,11 @@ update). For more information, see the I<ReturnValues> description
 below.
 
 To prevent a new item from replacing an existing item, use a
-conditional put operation with I<ComparisonOperator> set to C<NULL> for
-the primary key attribute, or attributes.
+conditional expression that contains the C<attribute_not_exists>
+function with the name of the attribute being used as the partition key
+for the table. Since every record must contain that attribute, the
+C<attribute_not_exists> function will only succeed if no matching item
+exists.
 
 For more information about using this API, see Working with Items in
 the I<Amazon DynamoDB Developer Guide>.
@@ -614,13 +725,13 @@ Returns: a L<Paws::DynamoDB::QueryOutput> instance
   A I<Query> operation uses the primary key of a table or a secondary
 index to directly access items from that table or index.
 
-Use the I<KeyConditionExpression> parameter to provide a specific hash
-key value. The I<Query> operation will return all of the items from the
-table or index with that hash key value. You can optionally narrow the
-scope of the I<Query> operation by specifying a range key value and a
-comparison operator in I<KeyConditionExpression>. You can use the
-I<ScanIndexForward> parameter to get results in forward or reverse
-order, by range key or by index key.
+Use the I<KeyConditionExpression> parameter to provide a specific value
+for the partition key. The I<Query> operation will return all of the
+items from the table or index with that partition key value. You can
+optionally narrow the scope of the I<Query> operation by specifying a
+sort key value and a comparison operator in I<KeyConditionExpression>.
+You can use the I<ScanIndexForward> parameter to get results in forward
+or reverse order, by sort key.
 
 Queries that do not return results consume the minimum number of read
 capacity units for that type of read operation.
@@ -663,10 +774,11 @@ can request a parallel I<Scan> operation by providing the I<Segment>
 and I<TotalSegments> parameters. For more information, see Parallel
 Scan in the I<Amazon DynamoDB Developer Guide>.
 
-By default, I<Scan> uses eventually consistent reads when acessing the
-data in the table or local secondary index. However, you can use
-strongly consistent reads instead by setting the I<ConsistentRead>
-parameter to I<true>.
+By default, I<Scan> uses eventually consistent reads when accessing the
+data in a table; therefore, the result set might not include the
+changes to data in the table immediately before the operation began. If
+you need a consistent copy of the data, as of the time that the Scan
+begins, you can set the I<ConsistentRead> parameter to I<true>.
 
 
 =head2 UpdateItem(Key => L<Paws::DynamoDB::Key>, TableName => Str, [AttributeUpdates => L<Paws::DynamoDB::AttributeUpdates>, ConditionalOperator => Str, ConditionExpression => Str, Expected => L<Paws::DynamoDB::ExpectedAttributeMap>, ExpressionAttributeNames => L<Paws::DynamoDB::ExpressionAttributeNameMap>, ExpressionAttributeValues => L<Paws::DynamoDB::ExpressionAttributeValueMap>, ReturnConsumedCapacity => Str, ReturnItemCollectionMetrics => Str, ReturnValues => Str, UpdateExpression => Str])
@@ -680,8 +792,7 @@ it does not already exist. You can put, delete, or add attribute
 values. You can also perform a conditional update on an existing item
 (insert a new attribute name-value pair if it doesn't exist, or replace
 an existing name-value pair if it has certain expected attribute
-values). If conditions are specified and the item does not exist, then
-the operation fails and a new item is not created.
+values).
 
 You can also return the item's attribute values in the same
 I<UpdateItem> operation using the I<ReturnValues> parameter.
