@@ -88,7 +88,7 @@ volume, in GiB.
 =item *
 
 C<block-device-mapping.volume-type> - The volume type of the EBS volume
-(C<gp2> | C<standard> | C<io1>).
+(C<gp2> | C<io1> | C<st1 >| C<sc1> | C<standard>).
 
 =item *
 
