@@ -5,6 +5,7 @@ package Paws::EC2::ReplaceRoute;
   has DryRun => (is => 'ro', isa => 'Bool', traits => ['NameInRequest'], request_name => 'dryRun' );
   has GatewayId => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'gatewayId' );
   has InstanceId => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'instanceId' );
+  has NatGatewayId => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'natGatewayId' );
   has NetworkInterfaceId => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'networkInterfaceId' );
   has RouteTableId => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'routeTableId' , required => 1);
   has VpcPeeringConnectionId => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'vpcPeeringConnectionId' );
@@ -41,41 +42,54 @@ Values for attributes that are native types (Int, String, Float, etc) can passed
 
 =head2 B<REQUIRED> DestinationCidrBlock => Str
 
-  The CIDR address block used for the destination match. The value you
+The CIDR address block used for the destination match. The value you
 provide must match the CIDR of an existing route in the table.
 
 
+
 =head2 DryRun => Bool
 
-  Checks whether you have the required permissions for the action,
+Checks whether you have the required permissions for the action,
 without actually making the request, and provides an error response. If
 you have the required permissions, the error response is
 C<DryRunOperation>. Otherwise, it is C<UnauthorizedOperation>.
 
 
+
 =head2 GatewayId => Str
 
-  The ID of an Internet gateway or virtual private gateway.
+The ID of an Internet gateway or virtual private gateway.
+
 
 
 =head2 InstanceId => Str
 
-  The ID of a NAT instance in your VPC.
+The ID of a NAT instance in your VPC.
+
+
+
+=head2 NatGatewayId => Str
+
+The ID of a NAT gateway.
+
 
 
 =head2 NetworkInterfaceId => Str
 
-  The ID of a network interface.
+The ID of a network interface.
+
 
 
 =head2 B<REQUIRED> RouteTableId => Str
 
-  The ID of the route table.
+The ID of the route table.
+
 
 
 =head2 VpcPeeringConnectionId => Str
 
-  The ID of a VPC peering connection.
+The ID of a VPC peering connection.
+
 
 
 
