@@ -39,6 +39,10 @@ Values for attributes that are native types (Int, String, Float, etc) can passed
 
 The attribute to reset.
 
+You can only reset the following attributes: C<kernel> | C<ramdisk> |
+C<sourceDestCheck>. To change an instance attribute, use
+ModifyInstanceAttribute.
+
 Valid values are: C<"instanceType">, C<"kernel">, C<"ramdisk">, C<"userData">, C<"disableApiTermination">, C<"instanceInitiatedShutdownBehavior">, C<"rootDeviceName">, C<"blockDeviceMapping">, C<"productCodes">, C<"sourceDestCheck">, C<"groupSet">, C<"ebsOptimized">, C<"sriovNetSupport">
 
 =head2 DryRun => Bool
