@@ -219,6 +219,11 @@ C<desiredCount>, Amazon ECS spawns another instantiation of the task in
 the specified cluster. To update an existing service, see
 UpdateService.
 
+In addition to maintaining the desired count of tasks in your service,
+you can optionally run your service behind a load balancer. The load
+balancer distributes traffic across the tasks that are associated with
+the service.
+
 You can optionally specify a deployment configuration for your service.
 During a deployment (which is triggered by changing the task definition
 of a service with an UpdateService operation), the service scheduler
@@ -330,8 +335,11 @@ but it does not terminate the EC2 instance; if you are finished using
 the instance, be sure to terminate it in the Amazon EC2 console to stop
 billing.
 
-When you terminate a container instance, it is automatically
-deregistered from your cluster.
+If you terminate a running container instance with a connected Amazon
+ECS container agent, the agent automatically deregisters the instance
+from your cluster (stopped container instances or instances with
+disconnected agents are not automatically deregistered when
+terminated).
 
 
 =head2 DeregisterTaskDefinition(TaskDefinition => Str)
@@ -447,7 +455,7 @@ Returns: a L<Paws::ECS::ListServicesResponse> instance
   Lists the services that are running in a specified cluster.
 
 
-=head2 ListTaskDefinitionFamilies([FamilyPrefix => Str, MaxResults => Int, NextToken => Str])
+=head2 ListTaskDefinitionFamilies([FamilyPrefix => Str, MaxResults => Int, NextToken => Str, Status => Str])
 
 Each argument is described in detail in: L<Paws::ECS::ListTaskDefinitionFamilies>
 
@@ -455,8 +463,12 @@ Returns: a L<Paws::ECS::ListTaskDefinitionFamiliesResponse> instance
 
   Returns a list of task definition families that are registered to your
 account (which may include task definition families that no longer have
-any C<ACTIVE> task definitions). You can filter the results with the
-C<familyPrefix> parameter.
+any C<ACTIVE> task definition revisions).
+
+You can filter out task definition families that do not contain any
+C<ACTIVE> task definition revisions by setting the C<status> parameter
+to C<ACTIVE>. You can also filter the results with the C<familyPrefix>
+parameter.
 
 
 =head2 ListTaskDefinitions([FamilyPrefix => Str, MaxResults => Int, NextToken => Str, Sort => Str, Status => Str])
