@@ -9,7 +9,7 @@ package Paws::EFS::CreateFileSystem;
   class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/2015-02-01/file-systems');
   class_has _api_method  => (isa => 'Str', is => 'ro', default => 'POST');
   class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EFS::FileSystemDescription');
-  class_has _result_key => (isa => 'Str', is => 'ro', default => 'CreateFileSystemResult');
+  class_has _result_key => (isa => 'Str', is => 'ro');
 1;
 
 ### main pod documentation begin ###
@@ -37,11 +37,12 @@ Values for attributes that are native types (Int, String, Float, etc) can passed
 
 =head2 B<REQUIRED> CreationToken => Str
 
-  String of up to 64 ASCII characters. Amazon EFS uses this to ensure
+String of up to 64 ASCII characters. Amazon EFS uses this to ensure
 idempotent creation.
 
 
 
+
 =head1 SEE ALSO
 
 This class forms part of L<Paws>, documenting arguments for method CreateFileSystem in L<Paws::EFS>
