@@ -1,8 +1,7 @@
 
-package Paws::ELB::CreateLoadBalancerPolicyOutput {
+package Paws::ELB::CreateLoadBalancerPolicyOutput;
   use Moose;
 
-}
 1;
 
 ### main pod documentation begin ###
