@@ -4,6 +4,7 @@ package Paws::EMR::ListInstances;
   has ClusterId => (is => 'ro', isa => 'Str', required => 1);
   has InstanceGroupId => (is => 'ro', isa => 'Str');
   has InstanceGroupTypes => (is => 'ro', isa => 'ArrayRef[Str]');
+  has InstanceStates => (is => 'ro', isa => 'ArrayRef[Str]');
   has Marker => (is => 'ro', isa => 'Str');
 
   use MooseX::ClassAttribute;
@@ -54,6 +55,13 @@ The type of instance group for which to list the instances.
 
 
 
+=head2 InstanceStates => ArrayRef[Str]
+
+A list of instance states that will filter the instances returned with
+this request.
+
+
+
 =head2 Marker => Str
 
 The pagination token that indicates the next set of results to
