@@ -1,6 +1,7 @@
 package Paws::ElastiCache::Parameter;
   use Moose;
   has AllowedValues => (is => 'ro', isa => 'Str');
+  has ChangeType => (is => 'ro', isa => 'Str');
   has DataType => (is => 'ro', isa => 'Str');
   has Description => (is => 'ro', isa => 'Str');
   has IsModifiable => (is => 'ro', isa => 'Bool');
@@ -49,6 +50,14 @@ ElastiCache behavior.
   The valid range of values for the parameter.
 
 
+=head2 ChangeType => Str
+
+  ChangeType indicates whether a change to the parameter will be applied
+immediately or requires a reboot for the change to be applied. You can
+force a reboot or wait until the next maintenance window's reboot. For
+more information, see Rebooting a Cluster.
+
+
 =head2 DataType => Str
 
   The valid data type for the parameter.
