@@ -37,6 +37,10 @@ Values for attributes that are native types (Int, String, Float, etc) can passed
 
 The name of the instance profile to delete.
 
+The regex pattern for this parameter is a string of characters
+consisting of upper and lowercase alphanumeric characters with no
+spaces. You can also include any of the following characters: =,.@-
+
 
 
 
