@@ -38,6 +38,10 @@ Values for attributes that are native types (Int, String, Float, etc) can passed
 The serial number that uniquely identifies the MFA device. For virtual
 MFA devices, the serial number is the same as the ARN.
 
+The regex pattern for this parameter is a string of characters
+consisting of upper and lowercase alphanumeric characters with no
+spaces. You can also include any of the following characters: =/:,.@-
+
 
 
 
