@@ -40,12 +40,16 @@ Values for attributes that are native types (Int, String, Float, etc) can passed
 
 An authentication code emitted by the device.
 
+The format for this parameter is a string of 6 digits.
+
 
 
 =head2 B<REQUIRED> AuthenticationCode2 => Str
 
 A subsequent authentication code emitted by the device.
 
+The format for this parameter is a string of 6 digits.
+
 
 
 =head2 B<REQUIRED> SerialNumber => Str
@@ -53,11 +57,19 @@ A subsequent authentication code emitted by the device.
 The serial number that uniquely identifies the MFA device. For virtual
 MFA devices, the serial number is the device ARN.
 
+The regex pattern for this parameter is a string of characters
+consisting of upper and lowercase alphanumeric characters with no
+spaces. You can also include any of the following characters: =/:,.@-
+
 
 
 =head2 B<REQUIRED> UserName => Str
 
-The name of the user for whom you want to enable the MFA device.
+The name of the IAM user for whom you want to enable the MFA device.
+
+The regex pattern for this parameter is a string of characters
+consisting of upper and lowercase alphanumeric characters with no
+spaces. You can also include any of the following characters: =,.@-
 
 
 
