@@ -36,10 +36,13 @@ Values for attributes that are native types (Int, String, Float, etc) can passed
 
 =head2 B<REQUIRED> OpenIDConnectProviderArn => Str
 
-The Amazon Resource Name (ARN) of the IAM OpenID Connect (OIDC)
-provider to update the thumbprint for. You can get a list of OIDC
+The Amazon Resource Name (ARN) of the IAM OIDC provider resource object
+for which you want to update the thumbprint. You can get a list of OIDC
 provider ARNs by using the ListOpenIDConnectProviders action.
 
+For more information about ARNs, see Amazon Resource Names (ARNs) and
+AWS Service Namespaces in the I<AWS General Reference>.
+
 
 
 =head2 B<REQUIRED> ThumbprintList => ArrayRef[Str]
