@@ -38,7 +38,7 @@ Values for attributes that are native types (Int, String, Float, etc) can passed
 
 =head2 AssessmentRunArns => ArrayRef[Str]
 
-The ARNs of the assessment run(s) that generate the findings that you
+The ARNs of the assessment runs that generate the findings that you
 want to list.
 
 
@@ -65,9 +65,9 @@ want in the response. The default value is 10. The maximum value is
 =head2 NextToken => Str
 
 You can use this parameter when paginating results. Set the value of
-this parameter to 'null' on your first call to the B<ListFindings>
+this parameter to null on your first call to the B<ListFindings>
 action. Subsequent calls to the action fill B<nextToken> in the request
-with the value of B<NextToken> from previous response to continue
+with the value of B<NextToken> from the previous response to continue
 listing data.
 
 
