@@ -10,7 +10,7 @@ package Paws::IoT::DetachThingPrincipal;
   class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/things/{thingName}/principals');
   class_has _api_method  => (isa => 'Str', is => 'ro', default => 'DELETE');
   class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::IoT::DetachThingPrincipalResponse');
-  class_has _result_key => (isa => 'Str', is => 'ro', default => 'DetachThingPrincipalResult');
+  class_has _result_key => (isa => 'Str', is => 'ro');
 1;
 
 ### main pod documentation begin ###
@@ -38,12 +38,14 @@ Values for attributes that are native types (Int, String, Float, etc) can passed
 
 =head2 B<REQUIRED> Principal => Str
 
-  The principal.
+The principal.
+
 
 
 =head2 B<REQUIRED> ThingName => Str
 
-  The name of the thing.
+The name of the thing.
+
 
 
 
