@@ -40,11 +40,14 @@ globally unique identifier or the fully specified ARN to a key.
 
 =over
 
-=item * Key ARN Example -
+=item *
+
+Key ARN Example -
 arn:aws:kms:us-east-1:123456789012:key/12345678-1234-1234-1234-123456789012
 
-=item * Globally Unique Key ID Example -
-12345678-1234-1234-1234-123456789012
+=item *
+
+Globally Unique Key ID Example - 12345678-1234-1234-1234-123456789012
 
 =back
 
