@@ -57,16 +57,23 @@ ARN to either an alias or a key, or an alias name prefixed by "alias/".
 
 =over
 
-=item * Key ARN Example -
+=item *
+
+Key ARN Example -
 arn:aws:kms:us-east-1:123456789012:key/12345678-1234-1234-1234-123456789012
 
-=item * Alias ARN Example -
+=item *
+
+Alias ARN Example -
 arn:aws:kms:us-east-1:123456789012:alias/MyAliasName
 
-=item * Globally Unique Key ID Example -
-12345678-1234-1234-1234-123456789012
+=item *
 
-=item * Alias Name Example - alias/MyAliasName
+Globally Unique Key ID Example - 12345678-1234-1234-1234-123456789012
+
+=item *
+
+Alias Name Example - alias/MyAliasName
 
 =back
 
@@ -77,7 +84,7 @@ arn:aws:kms:us-east-1:123456789012:alias/MyAliasName
 
 A list of grant tokens.
 
-For more information, go to Grant Tokens in the I<AWS Key Management
+For more information, see Grant Tokens in the I<AWS Key Management
 Service Developer Guide>.
 
 
