@@ -39,6 +39,16 @@ package Paws::Kinesis;
     my $call_object = $self->new_with_coercions('Paws::Kinesis::DescribeStream', @_);
     return $self->caller->do_call($self, $call_object);
   }
+  sub DisableEnhancedMonitoring {
+    my $self = shift;
+    my $call_object = $self->new_with_coercions('Paws::Kinesis::DisableEnhancedMonitoring', @_);
+    return $self->caller->do_call($self, $call_object);
+  }
+  sub EnableEnhancedMonitoring {
+    my $self = shift;
+    my $call_object = $self->new_with_coercions('Paws::Kinesis::EnableEnhancedMonitoring', @_);
+    return $self->caller->do_call($self, $call_object);
+  }
   sub GetRecords {
     my $self = shift;
     my $call_object = $self->new_with_coercions('Paws::Kinesis::GetRecords', @_);
@@ -90,7 +100,7 @@ package Paws::Kinesis;
     return $self->caller->do_call($self, $call_object);
   }
 
-  sub operations { qw/AddTagsToStream CreateStream DecreaseStreamRetentionPeriod DeleteStream DescribeStream GetRecords GetShardIterator IncreaseStreamRetentionPeriod ListStreams ListTagsForStream MergeShards PutRecord PutRecords RemoveTagsFromStream SplitShard / }
+  sub operations { qw/AddTagsToStream CreateStream DecreaseStreamRetentionPeriod DeleteStream DescribeStream DisableEnhancedMonitoring EnableEnhancedMonitoring GetRecords GetShardIterator IncreaseStreamRetentionPeriod ListStreams ListTagsForStream MergeShards PutRecord PutRecords RemoveTagsFromStream SplitShard / }
 
 1;
 
@@ -118,10 +128,10 @@ Paws::Kinesis - Perl Interface to AWS Amazon Kinesis
 
 =head1 DESCRIPTION
 
-Amazon Kinesis Service API Reference
+Amazon Kinesis Streams Service API Reference
 
-Amazon Kinesis is a managed service that scales elastically for real
-time processing of streaming big data.
+Amazon Kinesis Streams is a managed service that scales elastically for
+real time processing of streaming big data.
 
 =head1 METHODS
 
@@ -144,11 +154,11 @@ Each argument is described in detail in: L<Paws::Kinesis::CreateStream>
 
 Returns: nothing
 
-  Creates a Amazon Kinesis stream. A stream captures and transports data
+  Creates an Amazon Kinesis stream. A stream captures and transports data
 records that are continuously emitted from different data sources or
-I<producers>. Scale-out within an Amazon Kinesis stream is explicitly
-supported by means of shards, which are uniquely identified groups of
-data records in an Amazon Kinesis stream.
+I<producers>. Scale-out within a stream is explicitly supported by
+means of shards, which are uniquely identified groups of data records
+in a stream.
 
 You specify and control the number of shards that a stream is composed
 of. Each shard can support reads up to 5 transactions per second, up to
@@ -182,8 +192,9 @@ point in time.
 
 =back
 
-For the default shard limit for an AWS account, see Amazon Kinesis
-Limits. If you need to increase this limit, contact AWS Support.
+For the default shard limit for an AWS account, see Streams Limits in
+the I<Amazon Kinesis Streams Developer Guide>. If you need to increase
+this limit, contact AWS Support.
 
 You can use C<DescribeStream> to check the stream status, which is
 returned in C<StreamStatus>.
@@ -197,9 +208,9 @@ Each argument is described in detail in: L<Paws::Kinesis::DecreaseStreamRetentio
 
 Returns: nothing
 
-  Decreases the stream's retention period, which is the length of time
-data records are accessible after they are added to the stream. The
-minimum value of a streamE<rsquo>s retention period is 24 hours.
+  Decreases the Amazon Kinesis stream's retention period, which is the
+length of time data records are accessible after they are added to the
+stream. The minimum value of a stream's retention period is 24 hours.
 
 This operation may result in lost data. For example, if the stream's
 retention period is 48 hours and is decreased to 24 hours, any data
@@ -212,10 +223,10 @@ Each argument is described in detail in: L<Paws::Kinesis::DeleteStream>
 
 Returns: nothing
 
-  Deletes a stream and all its shards and data. You must shut down any
-applications that are operating on the stream before you delete the
-stream. If an application attempts to operate on a deleted stream, it
-will receive the exception C<ResourceNotFoundException>.
+  Deletes an Amazon Kinesis stream and all its shards and data. You must
+shut down any applications that are operating on the stream before you
+delete the stream. If an application attempts to operate on a deleted
+stream, it will receive the exception C<ResourceNotFoundException>.
 
 If the stream is in the C<ACTIVE> state, you can delete it. After a
 C<DeleteStream> request, the specified stream is in the C<DELETING>
@@ -240,16 +251,15 @@ Each argument is described in detail in: L<Paws::Kinesis::DescribeStream>
 
 Returns: a L<Paws::Kinesis::DescribeStreamOutput> instance
 
-  Describes the specified stream.
+  Describes the specified Amazon Kinesis stream.
 
 The information about the stream includes its current status, its
 Amazon Resource Name (ARN), and an array of shard objects. For each
 shard object, there is information about the hash key and sequence
 number ranges that the shard spans, and the IDs of any earlier shards
 that played in a role in creating the shard. A sequence number is the
-identifier associated with every record ingested in the Amazon Kinesis
-stream. The sequence number is assigned when a record is put into the
-stream.
+identifier associated with every record ingested in the stream. The
+sequence number is assigned when a record is put into the stream.
 
 You can limit the number of returned shards using the C<Limit>
 parameter. The number of shards in a stream may be too large to return
@@ -262,16 +272,40 @@ available, you can request them using the shard ID of the last shard
 returned. Specify this ID in the C<ExclusiveStartShardId> parameter in
 a subsequent request to C<DescribeStream>.
 
+There are no guarantees about the chronological order shards returned
+in C<DescribeStream> results. If you want to process shards in
+chronological order, use C<ParentShardId> to track lineage to the
+oldest shard.
+
 DescribeStream has a limit of 10 transactions per second per account.
 
 
+=head2 DisableEnhancedMonitoring(ShardLevelMetrics => ArrayRef[Str], StreamName => Str)
+
+Each argument is described in detail in: L<Paws::Kinesis::DisableEnhancedMonitoring>
+
+Returns: a L<Paws::Kinesis::EnhancedMonitoringOutput> instance
+
+  Disables enhanced monitoring.
+
+
+=head2 EnableEnhancedMonitoring(ShardLevelMetrics => ArrayRef[Str], StreamName => Str)
+
+Each argument is described in detail in: L<Paws::Kinesis::EnableEnhancedMonitoring>
+
+Returns: a L<Paws::Kinesis::EnhancedMonitoringOutput> instance
+
+  Enables enhanced Amazon Kinesis stream monitoring for shard-level
+metrics.
+
+
 =head2 GetRecords(ShardIterator => Str, [Limit => Int])
 
 Each argument is described in detail in: L<Paws::Kinesis::GetRecords>
 
 Returns: a L<Paws::Kinesis::GetRecordsOutput> instance
 
-  Gets data records from a shard.
+  Gets data records from an Amazon Kinesis stream's shard.
 
 Specify a shard iterator using the C<ShardIterator> parameter. The
 shard iterator specifies the position in the shard from which you want
@@ -280,7 +314,9 @@ available in the portion of the shard that the iterator points to,
 GetRecords returns an empty list. Note that it might take multiple
 calls to get to a portion of the shard that contains records.
 
-You can scale by provisioning multiple shards. Your application should
+You can scale by provisioning multiple shards per stream while
+considering service limits (for more information, see Streams Limits in
+the I<Amazon Kinesis Streams Developer Guide>). Your application should
 have one thread per shard, each reading continuously from its stream.
 To read from a stream continually, call GetRecords in a loop. Use
 GetShardIterator to get the shard iterator to specify in the first
@@ -299,7 +335,7 @@ maximum supported size or throughput by using the C<Limit> parameter to
 specify the maximum number of records that GetRecords can return.
 Consider your average record size when determining this limit.
 
-The size of the data returned by GetRecords will vary depending on the
+The size of the data returned by GetRecords varies depending on the
 utilization of the shard. The maximum size of data that GetRecords can
 return is 10 MB. If a call returns this amount of data, subsequent
 calls made within the next 5 seconds throw
@@ -313,35 +349,36 @@ exceptions for longer than 1 second.
 
 To detect whether the application is falling behind in processing, you
 can use the C<MillisBehindLatest> response attribute. You can also
-monitor the stream using CloudWatch metrics (see Monitoring Amazon
-Kinesis in the I<Amazon Kinesis Developer Guide>).
+monitor the stream using CloudWatch metrics and other mechanisms (see
+Monitoring in the I<Amazon Kinesis Streams Developer Guide>).
 
 Each Amazon Kinesis record includes a value,
-C<ApproximateArrivalTimestamp>, that is set when an Amazon Kinesis
-stream successfully receives and stores a record. This is commonly
-referred to as a server-side timestamp, which is different than a
-client-side timestamp, where the timestamp is set when a data producer
-creates or sends the record to a stream. The timestamp has millisecond
-precision. There are no guarantees about the timestamp accuracy, or
-that the timestamp is always increasing. For example, records in a
-shard or across a stream might have timestamps that are out of order.
+C<ApproximateArrivalTimestamp>, that is set when a stream successfully
+receives and stores a record. This is commonly referred to as a
+server-side timestamp, whereas a client-side timestamp is set when a
+data producer creates or sends the record to a stream (a data producer
+is any data source putting data records into a stream, for example with
+PutRecords). The timestamp has millisecond precision. There are no
+guarantees about the timestamp accuracy, or that the timestamp is
+always increasing. For example, records in a shard or across a stream
+might have timestamps that are out of order.
 
 
-=head2 GetShardIterator(ShardId => Str, ShardIteratorType => Str, StreamName => Str, [StartingSequenceNumber => Str])
+=head2 GetShardIterator(ShardId => Str, ShardIteratorType => Str, StreamName => Str, [StartingSequenceNumber => Str, Timestamp => Str])
 
 Each argument is described in detail in: L<Paws::Kinesis::GetShardIterator>
 
 Returns: a L<Paws::Kinesis::GetShardIteratorOutput> instance
 
-  Gets a shard iterator. A shard iterator expires five minutes after it
-is returned to the requester.
+  Gets an Amazon Kinesis shard iterator. A shard iterator expires five
+minutes after it is returned to the requester.
 
-A shard iterator specifies the position in the shard from which to
-start reading data records sequentially. A shard iterator specifies
-this position using the sequence number of a data record in a shard. A
-sequence number is the identifier associated with every record ingested
-in the Amazon Kinesis stream. The sequence number is assigned when a
-record is put into the stream.
+A shard iterator specifies the shard position from which to start
+reading data records sequentially. The position is specified using the
+sequence number of a data record in a shard. A sequence number is the
+identifier associated with every record ingested in the stream, and is
+assigned when a record is put into the stream. Each stream has one or
+more shards.
 
 You must specify the shard iterator type. For example, you can set the
 C<ShardIteratorType> parameter to read exactly from the position
@@ -349,28 +386,28 @@ denoted by a specific sequence number by using the
 C<AT_SEQUENCE_NUMBER> shard iterator type, or right after the sequence
 number by using the C<AFTER_SEQUENCE_NUMBER> shard iterator type, using
 sequence numbers returned by earlier calls to PutRecord, PutRecords,
-GetRecords, or DescribeStream. You can specify the shard iterator type
-C<TRIM_HORIZON> in the request to cause C<ShardIterator> to point to
-the last untrimmed record in the shard in the system, which is the
-oldest data record in the shard. Or you can point to just after the
-most recent record in the shard, by using the shard iterator type
-C<LATEST>, so that you always read the most recent data in the shard.
+GetRecords, or DescribeStream. In the request, you can specify the
+shard iterator type C<AT_TIMESTAMP> to read records from an arbitrary
+point in time, C<TRIM_HORIZON> to cause C<ShardIterator> to point to
+the last untrimmed record in the shard in the system (the oldest data
+record in the shard), or C<LATEST> so that you always read the most
+recent data in the shard.
 
-When you repeatedly read from an Amazon Kinesis stream use a
-GetShardIterator request to get the first shard iterator for use in
-your first GetRecords request and then use the shard iterator returned
-by the GetRecords request in C<NextShardIterator> for subsequent reads.
-A new shard iterator is returned by every GetRecords request in
-C<NextShardIterator>, which you use in the C<ShardIterator> parameter
-of the next GetRecords request.
+When you read repeatedly from a stream, use a GetShardIterator request
+to get the first shard iterator for use in your first GetRecords
+request and for subsequent reads use the shard iterator returned by the
+GetRecords request in C<NextShardIterator>. A new shard iterator is
+returned by every GetRecords request in C<NextShardIterator>, which you
+use in the C<ShardIterator> parameter of the next GetRecords request.
 
 If a GetShardIterator request is made too often, you receive a
 C<ProvisionedThroughputExceededException>. For more information about
-throughput limits, see GetRecords.
+throughput limits, see GetRecords, and Streams Limits in the I<Amazon
+Kinesis Streams Developer Guide>.
 
-If the shard is closed, the iterator can't return more data, and
-GetShardIterator returns C<null> for its C<ShardIterator>. A shard can
-be closed using SplitShard or MergeShards.
+If the shard is closed, GetShardIterator returns a valid iterator for
+the last sequence number of the shard. Note that a shard can be closed
+as a result of using SplitShard or MergeShards.
 
 GetShardIterator has a limit of 5 transactions per second per account
 per open shard.
@@ -382,18 +419,18 @@ Each argument is described in detail in: L<Paws::Kinesis::IncreaseStreamRetentio
 
 Returns: nothing
 
-  Increases the stream's retention period, which is the length of time
-data records are accessible after they are added to the stream. The
-maximum value of a streamE<rsquo>s retention period is 168 hours (7
-days).
+  Increases the Amazon Kinesis stream's retention period, which is the
+length of time data records are accessible after they are added to the
+stream. The maximum value of a stream's retention period is 168 hours
+(7 days).
 
 Upon choosing a longer stream retention period, this operation will
 increase the time period records are accessible that have not yet
 expired. However, it will not make previous data that has expired
-(older than the streamE<rsquo>s previous retention period) accessible
-after the operation has been called. For example, if a streamE<rsquo>s
-retention period is set to 24 hours and is increased to 168 hours, any
-data that is older than 24 hours will remain inaccessible to consumer
+(older than the stream's previous retention period) accessible after
+the operation has been called. For example, if a stream's retention
+period is set to 24 hours and is increased to 168 hours, any data that
+is older than 24 hours will remain inaccessible to consumer
 applications.
 
 
@@ -403,7 +440,7 @@ Each argument is described in detail in: L<Paws::Kinesis::ListStreams>
 
 Returns: a L<Paws::Kinesis::ListStreamsOutput> instance
 
-  Lists your streams.
+  Lists your Amazon Kinesis streams.
 
 The number of streams may be too large to return from a single call to
 C<ListStreams>. You can limit the number of returned streams using the
@@ -438,21 +475,21 @@ Each argument is described in detail in: L<Paws::Kinesis::MergeShards>
 
 Returns: nothing
 
-  Merges two adjacent shards in a stream and combines them into a single
-shard to reduce the stream's capacity to ingest and transport data. Two
-shards are considered adjacent if the union of the hash key ranges for
-the two shards form a contiguous set with no gaps. For example, if you
-have two shards, one with a hash key range of 276...381 and the other
-with a hash key range of 382...454, then you could merge these two
-shards into a single shard that would have a hash key range of
-276...454. After the merge, the single child shard receives data for
-all hash key values covered by the two parent shards.
+  Merges two adjacent shards in an Amazon Kinesis stream and combines
+them into a single shard to reduce the stream's capacity to ingest and
+transport data. Two shards are considered adjacent if the union of the
+hash key ranges for the two shards form a contiguous set with no gaps.
+For example, if you have two shards, one with a hash key range of
+276...381 and the other with a hash key range of 382...454, then you
+could merge these two shards into a single shard that would have a hash
+key range of 276...454. After the merge, the single child shard
+receives data for all hash key values covered by the two parent shards.
 
 C<MergeShards> is called when there is a need to reduce the overall
 capacity of a stream because of excess capacity that is not being used.
 You must specify the shard to be merged and the adjacent shard for a
 stream. For more information about merging shards, see Merge Two Shards
-in the I<Amazon Kinesis Developer Guide>.
+in the I<Amazon Kinesis Streams Developer Guide>.
 
 If the stream is in the C<ACTIVE> state, you can call C<MergeShards>.
 If a stream is in the C<CREATING>, C<UPDATING>, or C<DELETING> state,
@@ -486,12 +523,11 @@ Each argument is described in detail in: L<Paws::Kinesis::PutRecord>
 
 Returns: a L<Paws::Kinesis::PutRecordOutput> instance
 
-  Writes a single data record from a producer into an Amazon Kinesis
-stream. Call C<PutRecord> to send data from the producer into the
-Amazon Kinesis stream for real-time ingestion and subsequent
-processing, one record at a time. Each shard can support writes up to
-1,000 records per second, up to a maximum data write total of 1 MB per
-second.
+  Writes a single data record into an Amazon Kinesis stream. Call
+C<PutRecord> to send data into the stream for real-time ingestion and
+subsequent processing, one record at a time. Each shard can support
+writes up to 1,000 records per second, up to a maximum data write total
+of 1 MB per second.
 
 You must specify the name of the stream that captures, stores, and
 transports the data; a partition key; and the data blob itself.
@@ -502,9 +538,9 @@ on.
 
 The partition key is used by Amazon Kinesis to distribute data across
 shards. Amazon Kinesis segregates the data records that belong to a
-data stream into multiple shards, using the partition key associated
-with each data record to determine which shard a given data record
-belongs to.
+stream into multiple shards, using the partition key associated with
+each data record to determine which shard a given data record belongs
+to.
 
 Partition keys are Unicode strings, with a maximum length limit of 256
 characters for each key. An MD5 hash function is used to map partition
@@ -513,24 +549,24 @@ shards using the hash key ranges of the shards. You can override
 hashing the partition key to determine the shard by explicitly
 specifying a hash value using the C<ExplicitHashKey> parameter. For
 more information, see Adding Data to a Stream in the I<Amazon Kinesis
-Developer Guide>.
+Streams Developer Guide>.
 
 C<PutRecord> returns the shard ID of where the data record was placed
 and the sequence number that was assigned to the data record.
 
-Sequence numbers generally increase over time. To guarantee strictly
-increasing ordering, use the C<SequenceNumberForOrdering> parameter.
-For more information, see Adding Data to a Stream in the I<Amazon
-Kinesis Developer Guide>.
+Sequence numbers increase over time and are specific to a shard within
+a stream, not across all shards within a stream. To guarantee strictly
+increasing ordering, write serially to a shard and use the
+C<SequenceNumberForOrdering> parameter. For more information, see
+Adding Data to a Stream in the I<Amazon Kinesis Streams Developer
+Guide>.
 
 If a C<PutRecord> request cannot be processed because of insufficient
 provisioned throughput on the shard involved in the request,
 C<PutRecord> throws C<ProvisionedThroughputExceededException>.
 
-By default, data records are accessible for only 24 hours from the time
-that they are added to an Amazon Kinesis stream. This retention period
-can be modified using the DecreaseStreamRetentionPeriod and
-IncreaseStreamRetentionPeriod operations.
+Data records are accessible for only 24 hours from the time that they
+are added to a stream.
 
 
 =head2 PutRecords(Records => ArrayRef[L<Paws::Kinesis::PutRecordsRequestEntry>], StreamName => Str)
@@ -539,10 +575,9 @@ Each argument is described in detail in: L<Paws::Kinesis::PutRecords>
 
 Returns: a L<Paws::Kinesis::PutRecordsOutput> instance
 
-  Writes multiple data records from a producer into an Amazon Kinesis
-stream in a single call (also referred to as a C<PutRecords> request).
-Use this operation to send data from a data producer into the Amazon
-Kinesis stream for data ingestion and processing.
+  Writes multiple data records into an Amazon Kinesis stream in a single
+call (also referred to as a C<PutRecords> request). Use this operation
+to send data into the stream for data ingestion and processing.
 
 Each C<PutRecords> request can support up to 500 records. Each record
 in the request can be as large as 1 MB, up to a limit of 5 MB for the
@@ -566,13 +601,15 @@ MD5 hash function is used to map partition keys to 128-bit integer
 values and to map associated data records to shards. As a result of
 this hashing mechanism, all data records with the same partition key
 map to the same shard within the stream. For more information, see
-Adding Data to a Stream in the I<Amazon Kinesis Developer Guide>.
+Adding Data to a Stream in the I<Amazon Kinesis Streams Developer
+Guide>.
 
 Each record in the C<Records> array may include an optional parameter,
 C<ExplicitHashKey>, which overrides the partition key to shard mapping.
 This parameter allows a data producer to determine explicitly the shard
 where the record is stored. For more information, see Adding Multiple
-Records with PutRecords in the I<Amazon Kinesis Developer Guide>.
+Records with PutRecords in the I<Amazon Kinesis Streams Developer
+Guide>.
 
 The C<PutRecords> response includes an array of response C<Records>.
 Each record in the response array directly correlates with a record in
@@ -599,8 +636,8 @@ C<ErrorMessage> provides more detailed information about the
 C<ProvisionedThroughputExceededException> exception including the
 account ID, stream name, and shard ID of the record that was throttled.
 For more information about partially successful responses, see Adding
-Multiple Records with PutRecords in the I<Amazon Kinesis Developer
-Guide>.
+Multiple Records with PutRecords in the I<Amazon Kinesis Streams
+Developer Guide>.
 
 By default, data records are accessible for only 24 hours from the time
 that they are added to an Amazon Kinesis stream. This retention period
@@ -614,7 +651,9 @@ Each argument is described in detail in: L<Paws::Kinesis::RemoveTagsFromStream>
 
 Returns: nothing
 
-  Deletes tags from the specified Amazon Kinesis stream.
+  Removes tags from the specified Amazon Kinesis stream. Removed tags are
+deleted and cannot be recovered after this operation successfully
+completes.
 
 If you specify a tag that does not exist, it is ignored.
 
@@ -625,14 +664,15 @@ Each argument is described in detail in: L<Paws::Kinesis::SplitShard>
 
 Returns: nothing
 
-  Splits a shard into two new shards in the stream, to increase the
-stream's capacity to ingest and transport data. C<SplitShard> is called
-when there is a need to increase the overall capacity of stream because
-of an expected increase in the volume of data records being ingested.
+  Splits a shard into two new shards in the Amazon Kinesis stream to
+increase the stream's capacity to ingest and transport data.
+C<SplitShard> is called when there is a need to increase the overall
+capacity of a stream because of an expected increase in the volume of
+data records being ingested.
 
 You can also use C<SplitShard> when a shard appears to be approaching
-its maximum utilization, for example, when the set of producers sending
-data into the specific shard are suddenly sending more than previously
+its maximum utilization; for example, the producers sending data into
+the specific shard are suddenly sending more than previously
 anticipated. You can also call C<SplitShard> to increase stream
 capacity, so that more Amazon Kinesis applications can simultaneously
 read data from the stream for real-time processing.
@@ -642,7 +682,8 @@ the position in the shard where the shard gets split in two. In many
 cases, the new hash key might simply be the average of the beginning
 and ending hash key, but it can be any hash key value in the range
 being mapped into the shard. For more information about splitting
-shards, see Split a Shard in the I<Amazon Kinesis Developer Guide>.
+shards, see Split a Shard in the I<Amazon Kinesis Streams Developer
+Guide>.
 
 You can use DescribeStream to determine the shard ID and hash key
 values for the C<ShardToSplit> and C<NewStartingHashKey> parameters
@@ -665,12 +706,13 @@ If the specified stream does not exist, C<DescribeStream> returns a
 C<ResourceNotFoundException>. If you try to create more shards than are
 authorized for your account, you receive a C<LimitExceededException>.
 
-For the default shard limit for an AWS account, see Amazon Kinesis
-Limits. If you need to increase this limit, contact AWS Support.
+For the default shard limit for an AWS account, see Streams Limits in
+the I<Amazon Kinesis Streams Developer Guide>. If you need to increase
+this limit, contact AWS Support.
 
-If you try to operate on too many streams in parallel using
-CreateStream, DeleteStream, MergeShards or SplitShard, you receive a
-C<LimitExceededException>.
+If you try to operate on too many streams simultaneously using
+CreateStream, DeleteStream, MergeShards, and/or SplitShard, you receive
+a C<LimitExceededException>.
 
 C<SplitShard> has limit of 5 transactions per second per account.
 
