@@ -12,7 +12,7 @@ package Paws::Lambda::ListEventSourceMappings;
   class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/2015-03-31/event-source-mappings/');
   class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
   class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Lambda::ListEventSourceMappingsResponse');
-  class_has _result_key => (isa => 'Str', is => 'ro', default => 'ListEventSourceMappingsResult');
+  class_has _result_key => (isa => 'Str', is => 'ro');
 1;
 
 ### main pod documentation begin ###
@@ -40,36 +40,42 @@ Values for attributes that are native types (Int, String, Float, etc) can passed
 
 =head2 EventSourceArn => Str
 
-  The Amazon Resource Name (ARN) of the Amazon Kinesis stream.
+The Amazon Resource Name (ARN) of the Amazon Kinesis stream.
+
 
 
 =head2 FunctionName => Str
 
-  The name of the Lambda function.
+The name of the Lambda function.
+
+You can specify the function name (for example, C<Thumbnail>) or you
+can specify Amazon Resource Name (ARN) of the function (for example,
+C<arn:aws:lambda:us-west-2:account-id:function:ThumbNail>). If you are
+using versioning, you can also provide a qualified function ARN (ARN
+that is qualified with function version or alias name as suffix). AWS
+Lambda also allows you to specify only the function name with the
+account ID qualifier (for example, C<account-id:Thumbnail>). Note that
+the length constraint applies only to the ARN. If you specify only the
+function name, it is limited to 64 character in length.
 
-You can specify an unqualified function name (for example, "Thumbnail")
-or you can specify Amazon Resource Name (ARN) of the function (for
-example, "arn:aws:lambda:us-west-2:account-id:function:ThumbNail"). AWS
-Lambda also allows you to specify only the account ID qualifier (for
-example, "account-id:Thumbnail"). Note that the length constraint
-applies only to the ARN. If you specify only the function name, it is
-limited to 64 character in length.
 
 
 =head2 Marker => Str
 
-  Optional string. An opaque pagination token returned from a previous
+Optional string. An opaque pagination token returned from a previous
 C<ListEventSourceMappings> operation. If present, specifies to continue
 the list from where the returning call left off.
 
 
+
 =head2 MaxItems => Int
 
-  Optional integer. Specifies the maximum number of event sources to
+Optional integer. Specifies the maximum number of event sources to
 return in response. This value must be greater than 0.
 
 
 
+
 =head1 SEE ALSO
 
 This class forms part of L<Paws>, documenting arguments for method ListEventSourceMappings in L<Paws::Lambda>
