@@ -75,20 +75,30 @@ Constraints:
 
 =over
 
-=item * If SourceIds are supplied, SourceType must also be provided.
+=item *
 
-=item * If the source type is a DB instance, then a
-C<DBInstanceIdentifier> must be supplied.
+If SourceIds are supplied, SourceType must also be provided.
 
-=item * If the source type is a DB security group, a
-C<DBSecurityGroupName> must be supplied.
+=item *
 
-=item * If the source type is a DB parameter group, a
-C<DBParameterGroupName> must be supplied.
-
-=item * If the source type is a DB snapshot, a C<DBSnapshotIdentifier>
+If the source type is a DB instance, then a C<DBInstanceIdentifier>
 must be supplied.
 
+=item *
+
+If the source type is a DB security group, a C<DBSecurityGroupName>
+must be supplied.
+
+=item *
+
+If the source type is a DB parameter group, a C<DBParameterGroupName>
+must be supplied.
+
+=item *
+
+If the source type is a DB snapshot, a C<DBSnapshotIdentifier> must be
+supplied.
+
 =back
 
 
