@@ -36,8 +36,7 @@ Values for attributes that are native types (Int, String, Float, etc) can passed
 
 =head2 B<REQUIRED> Content => Str
 
-A valid JSON string. For more information about the contents of this
-string, see SSM Document.
+A valid JSON string.
 
 
 
