@@ -1,6 +1,7 @@
 package Paws::SSM::DocumentIdentifier;
   use Moose;
   has Name => (is => 'ro', isa => 'Str');
+  has Owner => (is => 'ro', isa => 'Str');
   has PlatformTypes => (is => 'ro', isa => 'ArrayRef[Str]');
 1;
 
@@ -42,6 +43,11 @@ Describes the name of an SSM document.
   The name of the SSM document.
 
 
+=head2 Owner => Str
+
+  The AWS user account of the person who created the document.
+
+
 =head2 PlatformTypes => ArrayRef[Str]
 
   The operating system platform.
