@@ -16,8 +16,7 @@ Paws::STS::DecodeAuthorizationMessageResponse
 
 =head2 DecodedMessage => Str
 
-An XML document that contains the decoded message. For more
-information, see C<DecodeAuthorizationMessage>.
+An XML document that contains the decoded message.
 
 
 
