@@ -3,6 +3,7 @@ package Paws::WorkSpaces::WorkspaceRequest;
   has BundleId => (is => 'ro', isa => 'Str', required => 1);
   has DirectoryId => (is => 'ro', isa => 'Str', required => 1);
   has RootVolumeEncryptionEnabled => (is => 'ro', isa => 'Bool');
+  has Tags => (is => 'ro', isa => 'ArrayRef[Paws::WorkSpaces::Tag]');
   has UserName => (is => 'ro', isa => 'Str', required => 1);
   has UserVolumeEncryptionEnabled => (is => 'ro', isa => 'Bool');
   has VolumeEncryptionKey => (is => 'ro', isa => 'Str');
@@ -61,6 +62,11 @@ obtain a list of the directories that are available.
 encrypted.
 
 
+=head2 Tags => ArrayRef[L<Paws::WorkSpaces::Tag>]
+
+  The tags of the WorkSpace request.
+
+
 =head2 B<REQUIRED> UserName => Str
 
   The username that the WorkSpace is assigned to. This username must
