@@ -6,6 +6,7 @@ package Paws::API::ServiceToClass;
     acm => 'ACM',
     apigateway => 'ApiGateway',
     autoscaling => 'AutoScaling',
+   'application-autoscaling' => 'ApplicationAutoScaling',
     cloudformation => 'CloudFormation',
     cloudfront => 'CloudFront',
     cloudhsm => 'CloudHSM',
@@ -22,6 +23,7 @@ package Paws::API::ServiceToClass;
     config => 'Config',
     datapipeline => 'DataPipeline',
     devicefarm => 'DeviceFarm',
+    discovery => 'Discovery',
     directconnect => 'DirectConnect',
     dms => 'DMS',
     ds => 'DS',
